@@ -1,5 +1,7 @@
 /*
  * Copyright (c) 2011-2013 Sandia National Laboratories.  All rights reserved.
+ * Copyright (c) 2015      Research Organization for Information Science
+ *                         and Technology (RIST). All rights reserved.
  * $COPYRIGHT$
  * 
  * Additional copyrights may follow
@@ -643,7 +645,7 @@ ompi_osc_portals4_attach(struct ompi_win_t *win, void *base, size_t len)
 
 
 int
-ompi_osc_portals4_detach(struct ompi_win_t *win, void *base)
+ompi_osc_portals4_detach(struct ompi_win_t *win, const void *base)
 {
     return OMPI_SUCCESS;
 }
